@@ -97,7 +97,7 @@ class SignatureLine(object):
         # AND the data with 0xFF before the comparison is performed).
         #
         # We support the following operators:
-        for operator in ['&', '|', '*', '+', '-', '/', '~', '^']:
+        for operator in ['**', '<<', '>>', '&', '|', '*', '+', '-', '/', '~', '^']:
             # Look for each operator in self.type
             if operator in self.type:
                 # If found, split self.type into the type and operator value
@@ -625,14 +625,20 @@ class Magic(object):
                     try:
                         # If the operator value of this signature line is just
                         # an integer value, use it
-                        if isinstance(line.opvalue, int) or isinstance(line.opvalue, long):
+                        if isinstance(line.opvalue, int):
                             opval = line.opvalue
                         # Else, evaluate the complex expression
                         else:
                             opval = self._do_math(offset, line.opvalue)
 
                         # Perform the specified operation
-                        if line.operator == '&':
+                        if line.operator == '**':
+                            dvalue **= opval
+                        elif line.operator == '<<':
+                            dvalue <<= opval
+                        elif line.operator == '>>':
+                            dvalue >>= opval
+                        elif line.operator == '&':
                             dvalue &= opval
                         elif line.operator == '|':
                             dvalue |= opval
@@ -801,9 +807,11 @@ class Magic(object):
         if dlen is None:
             dlen = len(data)
 
+        sc = 0
         for signature in self.signatures:
             # Use regex to search the data block for potential signature
             # matches (fast)
+            sc += 1
             for match in signature.regex.finditer(data):
                 # Take the offset of the start of the signature into account
                 offset = match.start() - signature.offset
@@ -827,7 +835,7 @@ class Magic(object):
                                 continue
                             else:
                                 self.display_once.add(signature.title)
-
+                        
                         # Append the result to the results list
                         results.append(SignatureResult(**tags))
 
