@@ -59,9 +59,10 @@ class Extractor(Module):
         Option(short='D',
                long='dd',
                type=list,
-               dtype='type:ext:cmd',
+               dtype='type[:ext[:cmd]]',
                kwargs={'manual_rules': [], 'enabled': True},
-               description='Extract <type> signatures, give the files an extension of <ext>, and execute <cmd>'),
+               description='Extract <type> signatures (regular expression), give the files an extension of <ext>, '
+                           'and execute <cmd>'),
         Option(short='M',
                long='matryoshka',
                kwargs={'matryoshka': 8},
@@ -729,6 +730,7 @@ class Extractor(Module):
             if not callable(rule['cmd']):
                 ordered_rules.append(rule)
 
+        binwalk.core.common.debug("Found %d/%d matches for '%s'" % (len(ordered_rules), len(self.extract_rules), description))
         return ordered_rules
 
     def _parse_rule(self, rule):
@@ -860,6 +862,7 @@ class Extractor(Module):
                 except KeyboardInterrupt as e:
                     raise e
                 except Exception as e:
+                    retval = False
                     binwalk.core.common.warning("Internal extractor '%s' failed with exception: '%s'" % (str(cmd), str(e)))
             elif cmd:
                 # If not in debug mode, create a temporary file to redirect
